==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QDebugStateSaver_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qdebug.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDebugStateSaver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDebugStateSaver")
    QDebugStateSaver *_ptr = reinterpret_cast<QDebugStateSaver *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDebugStateSaver(QDebug&)
void __qt_construct_QDebugStateSaver_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDebugStateSaver(QDebug&)")
    jobject dbg0 = __java_arguments[0].l;
    QDebug& __qt_dbg0 = qtjambi_cast<QDebug& >(__jni_env, dbg0);
    QDebugStateSaver *__qt_this = new(__qtjambi_ptr) QDebugStateSaver(__qt_dbg0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDebugStateSaver
void __qt_destruct_QDebugStateSaver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDebugStateSaver")
    reinterpret_cast<QDebugStateSaver*>(ptr)->~QDebugStateSaver();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDebugStateSaver::QDebugStateSaver(QDebug&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDebugStateSaver_initialize_1native__Lio_qt_core_QDebugStateSaver_2Lio_qt_core_QDebug_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject dbg0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDebugStateSaver::QDebugStateSaver(QDebug&)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = dbg0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDebugStateSaver_0, sizeof(QDebugStateSaver), typeid(QDebugStateSaver), false, &deleter_QDebugStateSaver, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDebugStateSaver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDebugStateSaver>("QDebugStateSaver", "io/qt/core/QDebugStateSaver");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDebugStateSaver, {
        ConstructorInfo(&__qt_construct_QDebugStateSaver_0, "Lio/qt/core/QDebug;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDebugStateSaver);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QDebugStateSaver_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qdebug.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDebugStateSaver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDebugStateSaver")
    QDebugStateSaver *_ptr = reinterpret_cast<QDebugStateSaver *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDebugStateSaver(QDebug&)
void __qt_construct_QDebugStateSaver_ref_QDebug(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDebugStateSaver(QDebug&)")
    jobject dbg0 = __java_arguments[0].l;
    QDebug& __qt_dbg0 = qtjambi_cast<QDebug& >(__jni_env, dbg0);
    QDebugStateSaver *__qt_this = new(__qtjambi_ptr) QDebugStateSaver(__qt_dbg0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDebugStateSaver::QDebugStateSaver(QDebug&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDebugStateSaver_initialize_1native__Lio_qt_core_QDebugStateSaver_2Lio_qt_core_QDebug_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject dbg0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDebugStateSaver::QDebugStateSaver(QDebug&)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = dbg0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDebugStateSaver_ref_QDebug, sizeof(QDebugStateSaver), typeid(QDebugStateSaver), false, &deleter_QDebugStateSaver, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDebugStateSaver
void __qt_destruct_QDebugStateSaver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDebugStateSaver")
    reinterpret_cast<QDebugStateSaver*>(ptr)->~QDebugStateSaver();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDebugStateSaver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDebugStateSaver>("QDebugStateSaver", "io/qt/core/QDebugStateSaver");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDebugStateSaver, {
        ConstructorInfo(&__qt_construct_QDebugStateSaver_ref_QDebug, "Lio/qt/core/QDebug;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDebugStateSaver);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
